# HandyPy

![travis](https://travis-ci.com/jiayiliu/handypy.svg?branch=main)  [![codecov](https://codecov.io/gh/jiayiliu/handypy/branch/main/graph/badge.svg?token=SKALHNC98F)](https://codecov.io/gh/jiayiliu/handypy)

[WIP] Handy python scripts.

See [Documentations](https://jiayiliu.github.io/handypy/) for usage.